==> email-reminder_0.7.3.orig.tar.gz: email-reminder-0.7.3/EmailReminder/BirthdayStore.pm <==
# This file is part of Email-Reminder.
#
# Email-Reminder is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# Email-Reminder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Email-Reminder; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

package EmailReminder::BirthdayStore;

use strict;
use warnings;

use Gtk2;
use Glib::Object::Subclass
    Glib::Object::,
    interfaces => [ Gtk2::TreeModel:: ],
    ;

use EmailReminder::BirthdayEvent;
use EmailReminder::EventStore;

require Exporter;
our @ISA = ("EmailReminder::EventStore", "Exporter");

use constant TRUE => 1;
use constant FALSE => 0; 

# Column indices
my $EMAIL_INDEX = 3;

sub init
{
    my ($this) = @_;

    $this->{TYPE} = EmailReminder::BirthdayEvent->get_type();
    $this->{NB_COLUMNS} = EmailReminder::BirthdayEvent->get_nb_fields();

    $this->EmailReminder::EventStore::init();
}

sub get_event_column
{
    my ($this, $event, $col) = @_;
    
    if ($col == $EMAIL_INDEX) {
        return $event->get_email();
    }
    else {
        return $this->EmailReminder::YearlyStore::get_event_column($event, $col);
    }
}

sub set_event_column
{
    my ($this, $event, $col, $new_value) = @_;

    if ($col == $EMAIL_INDEX) {
        $event->set_email($new_value);
    }
    else {
        $this->EmailReminder::YearlyStore::set_event_column($event, $col, $new_value);
    }
}

1;

==> email-reminder_0.7.8.orig.tar.gz: email-reminder-0.7.8/EmailReminder/BirthdayStore.pm <==
# This file is part of Email-Reminder.
#
# Email-Reminder is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# Email-Reminder is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Email-Reminder; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

package EmailReminder::BirthdayStore;

use strict;
use warnings;

use Gtk2;
use Glib::Object::Subclass
    Glib::Object::,
    interfaces => [ Gtk2::TreeModel:: ],
    ;

use EmailReminder::BirthdayEvent;
use EmailReminder::EventStore;

use base qw(EmailReminder::EventStore);

# Column indices
my $EMAIL_INDEX = 3;

sub init
{
    my ($self) = @_;

    $self->{TYPE} = EmailReminder::BirthdayEvent->get_type();
    $self->{NB_COLUMNS} = EmailReminder::BirthdayEvent->get_nb_fields();

    $self->EmailReminder::EventStore::init();
    return 1;
}

sub get_event_column
{
    my ($self, $event, $col) = @_;
    
    if ($col == $EMAIL_INDEX) {
        return $event->get_email();
    }
    else {
        return $self->EmailReminder::YearlyStore::get_event_column($event, $col);
    }
}

sub set_event_column
{
    my ($self, $event, $col, $new_value) = @_;

    if ($col == $EMAIL_INDEX) {
        $event->set_email($new_value);
    }
    else {
        $self->EmailReminder::YearlyStore::set_event_column($event, $col, $new_value);
    }
    return 1;
}

1;
